@@ -7,6 +7,7 @@ import logging
 
 from neurohive.integration.bitbucket import BitBucket
 from neurohive.integration.unitycloud import UnityCloud
+from neurohive.integration.appcenter import AppCenter
 
 
 def get_jira_name_from_branch(branch_name):
@@ -55,3 +56,13 @@ def create_and_build_from_prs():
     # запускаю
     for build_target in build_targets:
         uc._create_build(build_target['buildtargetid'])
+
+
+def cleanup_old_appcenter_build():
+    parser = argparse.ArgumentParser()
+    parser.add_argument("--app-name", type=str, required=True)
+    parser.add_argument("--owner", type=str, required=True)
+    parser.add_argument("--leave-num", type=int, default=10)
+    args = parser.parse_args()
+    ac = AppCenter(args.owner)
+    ac.cleanup_old_builds(args.app_name, args.leave_num)
